more_selectors
open | /demo/more_selectors.html |
assertTextPresent | More complex selectors |
click | button-one |
waitForText | logger | Keep trying until you get there.
assertText | logger | Keep trying until you get there.
click | log-reset |
assertText | logger |
click | button-one |
waitForText | logger | Keep trying until you get there.
assertText | logger | Keep trying until you get there.
click | button-one |
waitForTextPresent | Button button-one clicked. |
assertTextPresent | Button button-one clicked. |
click | log-reset |
waitForText | logger |
assertText | logger |
click | button-two |
waitForText | logger | Keep trying until you get there, from the second button.
assertText | logger | Keep trying until you get there, from the second button.
click | button-two |
waitForTextPresent | Button button-two clicked. |
assertTextPresent | Button button-two clicked. |